@@ -1,9 +1,9 @@
 # -*-cperl-*-
 #
 # Crypt::FDH - Full Domain Hash
-# Copyright (c) 2016-2017 Ashish Gulhati <crypt-fdh at hash.neo.tc>
+# Copyright (c) Ashish Gulhati <crypt-fdh at hash.neo.tc>
 #
-# $Id: lib/Crypt/FDH.pm v1.009 Sat Jun 10 00:08:07 PDT 2017 $
+# $Id: lib/Crypt/FDH.pm v1.010 Sat Oct 27 21:26:17 PDT 2018 $
 
 use strict;
 
@@ -17,7 +17,7 @@ use vars qw( @ISA $VERSION $AUTOLOAD );
 
 BEGIN {
   require Exporter;
-  our ( $VERSION ) = '$Revision: 1.009 $' =~ /\s+([\d\.]+)/;
+  our ( $VERSION ) = '$Revision: 1.010 $' =~ /\s+([\d\.]+)/;
   our @ISA         = qw(Exporter);
   our @EXPORT_OK   = qw(hash hexhash hexdigest fdh);
 }
@@ -60,8 +60,8 @@ Crypt::FDH - Full Domain Hash
 
 =head1 VERSION
 
- $Revision: 1.009 $
- $Date: Sat Jun 10 00:08:07 PDT 2017 $
+ $Revision: 1.010 $
+ $Date: Sat Oct 27 21:26:17 PDT 2018 $
 
 =head1 SYNOPSIS
 
@@ -118,10 +118,12 @@ L<http://search.cpan.org/dist/Crypt-FDH/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2016-2017 Ashish Gulhati.
+Copyright (c) Ashish Gulhati.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License 2.0.
+This software package is Open Software; you can use, redistribute,
+and/or modify it under the terms of the Open Artistic License 2.0.
 
-See http://www.perlfoundation.org/artistic_license_2_0 for the full
-license terms.
+Please see L<http://www.opensoftwr.org/oal20.txt> for the full license
+terms, and ensure that the license grant applies to you before using
+or modifying this software. By using or modifying this software, you
+indicate your agreement with the license terms.
